Author: jmcd
Date: 2005-03-17 21:07:19 +0000 (Thu, 17 Mar 2005)
New Revision: 5868

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=5868

Log:
Merge from 3.0: fix 2338, samba coredumps when OS/2 checks for long filename
support.

Modified:
   trunk/source/smbd/open.c


Changeset:
Modified: trunk/source/smbd/open.c
===================================================================
--- trunk/source/smbd/open.c    2005-03-17 20:29:18 UTC (rev 5867)
+++ trunk/source/smbd/open.c    2005-03-17 21:07:19 UTC (rev 5868)
@@ -1146,17 +1146,15 @@
                oplock_request = 0;
        }
 
        /* this is for OS/2 EAs - try and say we don't support them */
        if (strstr(fname,".+,;=[].")) {
                unix_ERR_class = ERRDOS;
                /* OS/2 Workplace shell fix may be main code stream in a later 
release. */ 
-#if 1 /* OS2_WPS_FIX - Recent versions of OS/2 need this. */
                unix_ERR_code = ERRcannotopen;
-#else /* OS2_WPS_FIX */
-               unix_ERR_code = ERROR_EAS_NOT_SUPPORTED;
-#endif /* OS2_WPS_FIX */
-
-               DEBUG(5,("open_file_shared: OS/2 EA's are not supported.\n"));
+               unix_ERR_ntstatus = NT_STATUS_OBJECT_NAME_NOT_FOUND;
+               DEBUG(5,("open_file_shared: OS/2 long filenames are not 
supported.\n"));
+               /* need to reset errno or DEVELOPER will cause us to coredump */
+               errno = 0;
                file_free(fsp);
                return NULL;
        }
@@ -1146,17 +1146,15 @@
        }
 
-       /* this is for OS/2 EAs - try and say we don't support them */
+       /* this is for OS/2 long file names - say we don't support them */
        if (strstr(fname,".+,;=[].")) {
                unix_ERR_class = ERRDOS;

Reply via email to